Structs
- Arguments
- Wrapper struct
- Authorize
Args - Check
Parse Args - Cli
- Basic Cedar CLI for evaluating authorization queries
- Evaluate
Args - Format
Args - Link
Args - NewArgs
- Optional
Policies Args - This struct contains the arguments that together specify an input policy or policy set, for commands where policies are optional.
- Optional
Schema Args - This struct contains the arguments that together specify an input schema, for commands where the schema is optional.
- Partially
Authorize Args - Policies
Args - This struct contains the arguments that together specify an input policy or policy set.
- Request
Args - This struct contains the arguments that together specify a request.
- RunTests
Args - Schema
Args - This struct contains the arguments that together specify an input schema.
- Symcc
Args - Symcc
Policies Args - This struct contains the arguments that together specify an input policy or policy set without linked policies.
- Symcc
TwoPolicies Args - Two policy-set comparison: policy set inputs without linked policies.
- TpeArgs
- Translate
Policy Args - Translate
Schema Args - TwoPolicy
Args - Two-policy comparison: policy inputs
- Validate
Args - Visualize
Args
Enums
- Cedar
Exit Code - Commands
- Error
Format - Policy
Format - Policy
Translation Direction - The direction of translation
- Schema
Format - Schema
Translation Direction - The direction of translation
- Symcc
Commands - Validation
Mode